@@ -293,10 +293,17 @@ class KACLDocument:
                     ):
                         comp_result = future_version.compare(last_version)
                     #   2.3 if 'last version' was NOT a 'post version' ensure 'post version' has same 'base version'
-                    elif future_version_base != last_version_base:
-                        comp_result = -1  # indicate error
                     else:
-                        comp_result = 1
+                        comp_result = future_version_base.compare(last_version_base)
+                        #  2.4 if 'last version' has same 'base version' as 'future version' this is ok, because we
+                        #  define post version as 'higher' than base version
+                        if comp_result == 0:
+                            comp_result = 1
+                elif (
+                    last_version.prerelease
+                    and post_release_version_prefix in last_version.prerelease
+                ):
+                    comp_result = future_version_base.compare(last_version_base)
                 else:
                     comp_result = future_version.compare(last_version)
             else:
